﻿define([
    // Dojo
    "dojo/_base/declare",
    "dijit/registry",
    // Dijit
    "dijit/_TemplatedMixin",
    "dijit/_Container",
    "dijit/layout/_LayoutWidget",
    //"dijit/layout/_ContentPane",
    "dijit/_WidgetsInTemplateMixin",
    "epi-cms/_ContentContextMixin",
    "epi/dependency",
    "epi/routes",
    "epi/shell/widget/dialog/Alert",
    "epi/shell/widget/dialog/Confirmation",
    //Custom
    "workspace/components/WorkspaceGrid",
    "workspace/commands/AddCurrentItem",
    "workspace/commands/ClearItems",
    "workspace/commands/Settings",
    "epi/shell/command/_WidgetCommandProviderMixin",
    "dojo/text!./Dashboard.html"
], function (
    // Dojo
    declare,
    registry,
    // Dijit
    _TemplatedMixin,
    _Container,
    _LayoutWidget,
    _WidgetsInTemplateMixin,
    _ContentContextMixin,
    dependency,
    routes,
    Alert,
    Confirmation,
    WorkspaceGrid,
    AddCurrentItem,
    ClearItems,
    Settings,
    _WidgetCommandProviderMixin,
    template
) {

    return declare(
        [_Container, _LayoutWidget, _TemplatedMixin, _WidgetsInTemplateMixin, _ContentContextMixin, _WidgetCommandProviderMixin], {
        templateString: template,
        widgetsInTemplate: true,
        store: null,
        context: null,

        contextChanged: function (context, callerData) {
            this.context = context;
            this.inherited(arguments);
        },

        _getRestPath: function (name) {
            return routes.getRestPath({ moduleArea: "lionbridgeconnector", storeName: name }); //moduleArea: 'app' for internal build | lionbridgeconnector for external build
        },
        //_publishNow: function() {
        //    this.store.put('-2');
        //    this._reloadGrid();
        //},
        _store: function () {
            var registry = dependency.resolve("epi.storeregistry");
            if (registry._stores["workspace.workspacestore"] === undefined) {
                registry.create("workspace.workspacestore", this._getRestPath("workspacestore"));
                registry.create("workspace.translationprojectstore", this._getRestPath("translationprojectstore"));
                registry.create("workspace.translationprojecteditorstore", this._getRestPath("translationprojecteditorstore"));
                registry.create("workspace.translationprojecttreestore", this._getRestPath("translationprojecttreestore"));
                registry.create("workspace.translationprojectblocktreestore", this._getRestPath("translationprojectblocktreestore"));
                registry.create("workspace.translationsearchitemsstore", this._getRestPath("translationsearchitemsstore"));
                registry.create("workspace.publishprojectstore", this._getRestPath("publishprojectstore"));
                registry.create("workspace.importprojectstore", this._getRestPath("importprojectstore"));
                registry.create("workspace.settingstore", this._getRestPath("settingstore"));
                registry.create("workspace.archiveprojectstore", this._getRestPath("archiveprojectstore"));
                registry.create("workspace.dashboardstore", this._getRestPath("dashboardstore"));
                registry.create("workspace.publishprojectlanguagestore", this._getRestPath("publishprojectlanguagestore"));
                registry.create("workspace.importprojectlanguagestore", this._getRestPath("importprojectlanguagestore"));
                registry.create("workspace.authenticationstore", this._getRestPath("authenticationstore"));
            }

            this.store = this.store || registry.get("workspace.workspacestore");
            return this.store;
        },

        
        startup: function () {
            var self = this;

            self.inherited(arguments);
            this._store();
            LionBridgeConnectorJs.projectServiceUrl = window.location.origin + this._getRestPath("translationprojectliststore");
            LionBridgeConnectorJs.projectTranslationLanguageServiceUrl = window.location.origin + this._getRestPath("projecttranslationlanguageliststore");
            LionBridgeConnectorJs.projectAssetServiceUrl = window.location.origin + this._getRestPath("projectassetliststore");

            //Service functions
            LionBridgeConnectorJs.workspacestoreServiceUrl = window.location.origin + this._getRestPath("workspacestore");
            LionBridgeConnectorJs.translationprojectstoreServiceUrl = window.location.origin + this._getRestPath("translationprojectstore");
            LionBridgeConnectorJs.translationprojecteditorstoreServiceUrl = window.location.origin + this._getRestPath("translationprojecteditorstore");
            LionBridgeConnectorJs.translationprojecttreestoreServiceUrl = window.location.origin + this._getRestPath("translationprojecttreestore");
            LionBridgeConnectorJs.translationprojectblocktreestoreServiceUrl = window.location.origin + this._getRestPath("translationprojectblocktreestore");
            LionBridgeConnectorJs.translationsearchitemsstoreServiceUrl = window.location.origin + this._getRestPath("translationsearchitemsstore");
            LionBridgeConnectorJs.publishprojectstoreServiceUrl = window.location.origin + this._getRestPath("publishprojectstore");
            LionBridgeConnectorJs.importprojectstoreServiceUrl = window.location.origin + this._getRestPath("importprojectstore");
            LionBridgeConnectorJs.publishprojectlanguagestoreServiceUrl = window.location.origin + this._getRestPath("publishprojectlanguagestore");
            LionBridgeConnectorJs.importprojectlanguagestoreServiceUrl = window.location.origin + this._getRestPath("importprojectlanguagestore");
            LionBridgeConnectorJs.settingstoreServiceUrl = window.location.origin + this._getRestPath("settingstore");
            LionBridgeConnectorJs.archiveprojectServiceUrl = window.location.origin + this._getRestPath("archiveprojectstore");

            //Object dojo
            LionBridgeConnectorJs.dependency = dependency;
            LionBridgeConnectorJs.Alert = Alert;
            LionBridgeConnectorJs.Confirmation = Confirmation;

            
            LionBridgeConnectorGrid.onRenderGrid();
            LionBridgeConnectorGrid.onRegisterClass();
        },
        postCreate: function () {
            var registry = dependency.resolve('epi.globalcommandregistry');
            if (registry) {
                var globalToolbar = registry._mappings['epi.cms.globalToolbar'];

                if (globalToolbar && globalToolbar.providers.length > 0) {
                    for (var i = 0; i < globalToolbar.providers.length; i++) {
                        var provider = globalToolbar.providers[i];
                        if (provider.commands.length > 0) {
                            for (var j = 0; j < provider.commands.length; j++) {
                                var command = provider.commands[j];
                                if (command.canExecute === undefined)
                                    break;
                                if (command.category === undefined || command.category !== "compare")
                                    continue;

                                command.canExecute = false;
                            }
                        }
                    }
                }
            }
        },
    });
});


var $n = jQuery;

var LionBridgeConnectorConstant = LionBridgeConnectorConstant || (function () {
    var archiveText = "Archive";
    var unArchiveText = "Unarchive";
    var archivedText = "Archived";
    var unArchivedText = "Unarchived";
    var viewArchivedJobs = "View Archived Projects";
    var viewUnarchivedJobs = "View Unarchived Projects";
    return {
        archiveText: archiveText,
        unArchiveText: unArchiveText,
        archivedText: archivedText,
        unArchivedText: unArchivedText,
        viewArchivedJobs: viewArchivedJobs,
        viewUnarchivedJobs: viewUnarchivedJobs,
    }
})();

var LionBridgeConnectorJs = LionBridgeConnectorJs || (function () {

    function onEditProject(id) {
        window.open(id, '_blank');
     }

    function onTranslate(id, item) {
        var confirmation = new LionBridgeConnectorJs.Confirmation({
            title: "Confirm Sending",
            description: "Are you sure you want to send?",
            onAction: function (confirmed) {
                if (confirmed) {
                    $n(item).parent().remove();
                    var registry = LionBridgeConnectorJs.dependency.resolve("epi.storeregistry");

                    setTimeout(function () {
                        var registry = LionBridgeConnectorJs.dependency.resolve("epi.storeregistry");
                        var store = registry.get("workspace.translationprojectstore");
                        store.put(id + ";" + "Sending").then(function (item) {
                            if (item.error) {
                                var errorDialog = new LionBridgeConnectorJs.Alert({
                                    heading: "Project not sent",
                                    description: "Something went wrong when sending the project due to: " + item.errorMessage,
                                    onAction: function () {
                                        if (typeof LionBridgeConnectorGrid !== "undefined") {
                                            LionBridgeConnectorGrid.onReloadGrid();
                                        }
                                        //Refresh gadget also
                                        if (typeof LionBridgeConnectorGadget !== "undefined") {
                                            LionBridgeConnectorGadget.reloadGadget();
                                        }
                                    }
                                });
                                errorDialog.show();
                            } else {

								var dialog = new LionBridgeConnectorJs.Alert({
                                    heading: "Project sending",
                                    description:
                                        "The project is sending... The status will update when processing is complete",
                                    onAction: function () {
                                        if (typeof LionBridgeConnectorGrid !== "undefined") {
                                    LionBridgeConnectorGrid.onReloadGrid();
									}
									//Refresh gadget also
									if (typeof LionBridgeConnectorGadget !== "undefined") {
										LionBridgeConnectorGadget.reloadGadget();
									}
                                    }
                                });

                                dialog.show();
                                //reload grid                               

                                store.put(id).then(function (sentItem) {

                                    if (sentItem.error) {
                                        var errorDialog = new LionBridgeConnectorJs.Alert({
                                            heading: "Project not sent",
                                            description: "Something went wrong when sending the project due to: " + sentItem.errorMessage,
                                            onAction: function () {
                                                if (typeof LionBridgeConnectorGrid !== "undefined") {
                                                    LionBridgeConnectorGrid.onReloadGrid();
                                                }
                                                //Refresh gadget also
                                                if (typeof LionBridgeConnectorGadget !== "undefined") {
                                                    LionBridgeConnectorGadget.reloadGadget();
                                                }
                                            }
                                        });
                                        errorDialog.show();
                                    }
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }
                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }

                                });
                                
                            }


                        });

                    }, 1);
                }
            }
        });
        confirmation.show();
    }

    function onImport(id, item) {
        var confirmation = new LionBridgeConnectorJs.Confirmation({
            title: "Import All Available",
            description: "Are you sure you want to import?",
            onAction: function (confirmed) {
                if (confirmed) {
                    //$n('.loadingDiv').fadeIn(500);
                    $n(item).parent().remove();
                    var registry = LionBridgeConnectorJs.dependency.resolve("epi.storeregistry");
                    var store = registry.get("workspace.importprojectlanguagestore");
                    var data = JSON.stringify({ id: id, language: '' });
                    store.put(data).then(function (item) {
                        if (item.error) {
                            var errorDialog = new LionBridgeConnectorJs.Alert({
                                heading: "Project not import",
                                description: "Something went wrong when importing the project: " + item.errorMessage,
                                onAction: function () {
                                    //reload grid
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }
                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }
                                }
                            });
                            errorDialog.show();
                        }
                        else {
                            var dialog = new LionBridgeConnectorJs.Alert({
                                heading: "Importing",
                                description: "The project is being Imported. The status will update when processing is complete.",
                                onAction: function () {
                                    //reload grid
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }
                                }
                            });
                            dialog.show();
                        }
                        //$n('.loadingDiv').fadeOut(500);
                    });

                    //reload grid
                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                        LionBridgeConnectorGrid.onReloadGrid();
                    }
                    //Refresh gadget also
                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                        LionBridgeConnectorGadget.reloadGadget();
                    }
                }
            }
        });
        confirmation.show();
    }

    function onPublish(id, item) {
        var confirmation = new LionBridgeConnectorJs.Confirmation({
            title: "Publish All Available",
            description: "Are you sure you want to publish?",
            onAction: function (confirmed) {
                if (confirmed) {
                    $n(item).parent().remove();
                    var registry = LionBridgeConnectorJs.dependency.resolve("epi.storeregistry");
                    var store = registry.get("workspace.publishprojectlanguagestore");
                    var data = JSON.stringify({ id: id, language: '' });
                    store.put(data).then(function (item) {
                        if (item.error) {
                            var errorDialog = new LionBridgeConnectorJs.Alert({
                                heading: "Project not publish",
                                description: "Something went wrong when publishing: " + item.errorMessage,
                                onAction: function () {
                                    //reload grid
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }
                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }
                                }
                            });
                            errorDialog.show();
                        } else {
                            var dialog = new LionBridgeConnectorJs.Alert({
                                heading: "Publishing",
                                description: "The project is being Published. The status will update when processing is complete.",
                                onAction: function () {
                                    //reload grid
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }

                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }
                                }
                            });
                            dialog.show();
                        }

                    });
                }
            }
        });
        confirmation.show();
    }

    function onCancel(id, item) {
        var confirmation = new LionBridgeConnectorJs.Confirmation({
            title: "Cancel project",
            description: "Are you sure you want to cancel the project?",
            onAction: function (confirmed) {
                if (confirmed) {
                    $n('.loadingDiv').fadeIn(500);
                    $n(item).parent().remove();

                    var registry = LionBridgeConnectorJs.dependency.resolve("epi.storeregistry");
                    var store = registry.get("workspace.translationprojectstore");
                    id = id + ";" + "cancel";
                    store.put(id).then(function (item) {
                        if (item !== undefined && item.error) {

                            var dialog = new LionBridgeConnectorJs.Alert({
                                heading: "Cancellation",
                                description: item.errorMessage,
                                onAction: function () {
                                    //reload grid
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }
                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }
                                }
                            });
                            dialog.show();
                        } else {
                            var dialog = new LionBridgeConnectorJs.Alert({
                                heading: "Cancelled",
                                description: "Please note that cancelling this project will not cause translation work to stop. Please contact Lionbridge to ensure that your work is stopped.",
                                onAction: function () {
                                    //reload grid
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }
                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }
                                }
                            });
                            dialog.show();
                        }
                        $n('.loadingDiv').fadeOut(500);
                    });
                }
            }
        });
        confirmation.show();
    }

    function onRemove(id, item) {
        var confirmation = new LionBridgeConnectorJs.Confirmation({
            title: "Remove project",
            description: "Are you sure you want to remove the project?",
            onAction: function (confirmed) {
                if (confirmed) {

                    $n('.loadingDiv').fadeIn(500);
                    $n(item).parent().remove();

                    var registry = LionBridgeConnectorJs.dependency.resolve("epi.storeregistry");
                    var store = registry.get("workspace.workspacestore");

                    store.remove(id).then(function (item) {
                        //reload grid
                        if (item !== undefined && item.error) {
                            var errorDialog = new Alert({
                                heading: "Remove Project",
                                description: "Something went wrong when removing the project due to: " + item.errorMessage,
                                onAction: function () {
                                    //reload grid
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }
                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }
                                }
                            });
                            errorDialog.show();
                        } else {
                            var dialog = new LionBridgeConnectorJs.Alert({
                                heading: "Removed",
                                description: "The Translation Project is being Removed.",
                                onAction: function () {
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }
                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }
                                }
                            });
                            dialog.show();
                        }
                        $n('.loadingDiv').fadeOut(500);
                    });

                    //reload grid
                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                        LionBridgeConnectorGrid.onReloadGrid();
                    }
                    //Refresh gadget also
                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                        LionBridgeConnectorGadget.reloadGadget();
                    }

                }
            }
        });
        confirmation.show();

    }


    function onImportByLanguage(id, language, item) {
        var confirmation = new LionBridgeConnectorJs.Confirmation({
            title: "Import",
            description: "Are you sure you want to import?",
            onAction: function (confirmed) {
                if (confirmed) {
                    var registry = LionBridgeConnectorJs.dependency.resolve("epi.storeregistry");
                    var store = registry.get("workspace.importprojectlanguagestore");
                    var data = JSON.stringify({ id: id, language: language });
                    store.put(data).then(function (result) {
                        if (result.error) {
                            var errorDialog = new LionBridgeConnectorJs.Alert({
                                heading: "Import",
                                description: "Something went wrong when importing the project: " + result.errorMessage
                            });
                            errorDialog.show();
                        }
                        else {
                            var dialog = new LionBridgeConnectorJs.Alert({
                                heading: "Importing",
                                description: "The selected Project languages are being Imported. The status will update when processing is complete.",
                                onAction: function () {
                                    
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }

                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }
                                }
                            });
                            dialog.show();
                        }

                    });
                }
            }
        });
        confirmation.show();
    }

    function onPublishByLanguage(id, language, item) {
        var confirmation = new LionBridgeConnectorJs.Confirmation({
            title: "Publish",
            description: "Are you sure you want to publish?",
            onAction: function (confirmed) {
                if (confirmed) {
                    var registry = LionBridgeConnectorJs.dependency.resolve("epi.storeregistry");
                    var store = registry.get("workspace.publishprojectlanguagestore");
                    var data = JSON.stringify({ id: id, language: language });
                    store.put(data).then(function (result) {
                        if (result.error) {
                            var errorDialog = new LionBridgeConnectorJs.Alert({
                                heading: "Publish",
                                description: "Something went wrong when publishing: " + result.errorMessage
                            });
                            errorDialog.show();
                        } else {
                            var dialog = new LionBridgeConnectorJs.Alert({
                                heading: "Publishing",
                                description: "The selected Project languages are being Published. The status will update when processing is complete.",
                                onAction: function () {
                                   
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.onReloadGrid();
                                    }

                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }
                                }
                            });
                            dialog.show();


                        }

                    });
                }
            }
        });
        confirmation.show();
    }

    function onArchive(id, archive, item) {
        var title = archive === true ? LionBridgeConnectorConstant.archiveText : LionBridgeConnectorConstant.unArchiveText;
        var heading = archive === true ? LionBridgeConnectorConstant.archivedText : LionBridgeConnectorConstant.unArchivedText;
        var confirmation = new LionBridgeConnectorJs.Confirmation({
            title: title,
            description: "Are you sure you want to " + title.toLowerCase() + " the project?",
            onAction: function (confirmed) {
                if (confirmed) {
                    $n('.loadingDiv').fadeIn(500);
                    var registry = LionBridgeConnectorJs.dependency.resolve("epi.storeregistry");
                    var store = registry.get("workspace.archiveprojectstore");
                    var data = JSON.stringify({ id: id, archive: archive });
                    store.put(data).then(function (result) {
                        if (result.error) {
                            var errorDialog = new LionBridgeConnectorJs.Alert({
                                heading: title,
                                description: "Something went wrong when " + title.toLowerCase() + ": " + result.errorMessage
                            });
                            errorDialog.show();
                        } else {
                            var dialog = new LionBridgeConnectorJs.Alert({
                                heading: heading,
                                description: "The project is being " + heading.toLowerCase() + ".",
                                onAction: function () {
                                    //reload grid
                                    //LionBridgeConnectorGrid.onReloadGrid();
                                    if (typeof LionBridgeConnectorGrid !== "undefined") {
                                        LionBridgeConnectorGrid.refreshChildGrid(item);
                                    }

                                    //Refresh gadget also
                                    if (typeof LionBridgeConnectorGadget !== "undefined") {
                                        LionBridgeConnectorGadget.reloadGadget();
                                    }
                                }
                            });
                            dialog.show();
                        }
                        $n('.loadingDiv').fadeOut(500);
                    });
                }
            }
        });
        confirmation.show();
    }

    function onGetArchiving() {
        //1-Archiving //0-UnArchiving
        var value = window.localStorage.getItem(archivingName);
        if (value === undefined || value === null || value === '')
            return "false";

        return value;
    }

    function onSetArchiving(value) {
        //1-Archiving //2-UnArchiving
        window.localStorage.setItem(archivingName, value);
    }

    var archivingName = 'lionbridge-archiving';
    //Service
    var projectServiceUrl;
    var projectTranslationLanguageServiceUrl;
    var projectAssetServiceUrl;
    var workspacestoreServiceUrl;
    var translationprojectstoreServiceUrl;
    var translationprojecteditorstoreServiceUrl;
    var translationprojecttreestoreServiceUrl;
    var translationprojectblocktreestoreServiceUrl;
    var translationsearchitemsstoreServiceUrl;
    var publishprojectstoreServiceUrl;
    var importprojectstoreServiceUrl;
    var publishprojectlanguagestoreServiceUrl;
    var importprojectlanguagestoreServiceUrl;
    var settingstoreServiceUrl;
    var dependency;
    var Alert;
    var Confirmation;
    var archiveprojectServiceUrl;

    return {
        onTranslate: onTranslate,
        onImport: onImport,
        onPublish: onPublish,
        onCancel: onCancel,
        onRemove: onRemove,
        onEditProject: onEditProject,
        onImportByLanguage: onImportByLanguage,
        onPublishByLanguage: onPublishByLanguage,
        //Service
        projectServiceUrl: projectServiceUrl,
        projectTranslationLanguageServiceUrl: projectTranslationLanguageServiceUrl,
        projectAssetServiceUrl: projectAssetServiceUrl,

        workspacestoreServiceUrl: workspacestoreServiceUrl,
        translationprojectstoreServiceUrl: translationprojectstoreServiceUrl,
        translationprojecteditorstoreServiceUrl: translationprojecteditorstoreServiceUrl,
        translationprojecttreestoreServiceUrl: translationprojecttreestoreServiceUrl,
        translationprojectblocktreestoreServiceUrl: translationprojectblocktreestoreServiceUrl,
        translationsearchitemsstoreServiceUrl: translationsearchitemsstoreServiceUrl,
        publishprojectstoreServiceUrl: publishprojectstoreServiceUrl,
        importprojectstoreServiceUrl: importprojectstoreServiceUrl,
        publishprojectlanguagestoreServiceUrl: publishprojectlanguagestoreServiceUrl,
        importprojectlanguagestoreServiceUrl: importprojectlanguagestoreServiceUrl,
        settingstoreServiceUrl: settingstoreServiceUrl,
        archiveprojectServiceUrl: archiveprojectServiceUrl,
        dependency: dependency,
        Alert: Alert,
        Confirmation: Confirmation,
        onGetArchiving: onGetArchiving,
        onSetArchiving: onSetArchiving,
        onArchive: onArchive,
    }
})();

var LionBridgeConnectorGrid = LionBridgeConnectorGrid || (function () {
    var pageSize = 20;
    var projectTable;
    var assetsListTable = {};

    function onRenderGrid() {
        //$n('#WorkspaceGrid').DataTable({
        //    orderCellsTop: true,
        //    fixedHeader: true
        //});
        var archivingValue = LionBridgeConnectorJs.onGetArchiving();

        var projectColumnSize = [];
        projectColumnSize["Project Name"] = "300px";
        projectColumnSize["Status"] = "100px";
        projectColumnSize["Actions"] = "150px";
        projectColumnSize["Freeway ID"] = "100px";
        projectColumnSize["Languages"] = "80px";
        projectColumnSize["Total Assets"] = "50px";
        projectColumnSize["Creator"] = "100px";
        projectColumnSize["Created"] = "100px";
        projectColumnSize["Due Date"] = "100px";
        projectColumnSize["Delivery Available"] = "100px";

        //define project table  : Project > Asset > Type
        //fix duplicate header incase grid exists.
        if ($n('#project5b83a1a738dc42f4b697404c2d324450 thead tr').length > 1) {
            $n('#project5b83a1a738dc42f4b697404c2d324450 thead tr').each(function (index) {
                if (index > 0) {
                    $n(this).remove();
                }
            });
        }

        $n('#project5b83a1a738dc42f4b697404c2d324450 thead tr').clone(true).appendTo('#project5b83a1a738dc42f4b697404c2d324450 thead');
        $n('#project5b83a1a738dc42f4b697404c2d324450 thead tr:eq(0) th').each(function (i) {
            var title = $n(this).text();
            if (title === '') {
                $n(this).html('');
            } else if (title !== 'Actions') {
                var titleFormat = title;
                if (title === "Delivery Available") {
                    titleFormat = "Delivery Avail";
                } else if (title === "Total Assets") {
                    titleFormat = "Assets";
                }
                $n(this).html('<input type="text" class="dijitTextBox" placeholder="' + titleFormat + '" style="width:' + projectColumnSize[title] + ';height: 30px;padding-left: 3px; -webkit-box-sizing: border-box; moz-box-sizing: border-box; box-sizing: border-box;"/>');
                $n('input', this).on('keyup change',
                    function () {
                        if (LionBridgeConnectorGrid.projectTable.column(i).search() !== this.value) {
                            LionBridgeConnectorGrid.projectTable.column(i).search(this.value).draw();
                        }
                    });
            } else {
                $n(this).html('<input type="hidden" style="width:150px"/>');
            }
        });

        var archiving = LionBridgeConnectorJs.onGetArchiving() === "true";

        var archiveButton = document.getElementById('archive6bb3b40543354773812682476d110c8f');

        if (archiveButton) {
            if (archiving) {
                archiveButton.innerHTML = LionBridgeConnectorConstant.viewUnarchivedJobs;
            } else {
                archiveButton.innerHTML = LionBridgeConnectorConstant.viewArchivedJobs;
            }
        }
        
        LionBridgeConnectorGrid.projectTable = $n('#project5b83a1a738dc42f4b697404c2d324450').DataTable({
            "fixedHeader": true,
            "processing": true,
            "lengthChange": false,
            "fixedColumns": true,
            "pageLength": pageSize,
            "autoWidth": false,
            "ajax": {
                "url": LionBridgeConnectorJs.projectServiceUrl + archivingValue,
            },
            "columns": [
                {
                    "className": 'detail-project',
                    "data": null,
                    "defaultContent": '',
                    "width": "35px",
                },
                { "data": "projectName", "className": "projectname" },
                { "data": "status", "className": "status" },
                { "data": "actions", "className": "action" },
                { "data": "freewayID", "className": "freewayid" },
                { "data": "languages", "className": "language" },
                { "data": "assets", "className": "asset" },
                { "data": "creator", "className": "creator" },
                {
                    data: {
                        _: "created.display",
                        sort: "created.timestamp"
                    }
                    , "className": "created"
                },
                {
                    data: {
                        _: "deadline.display",
                        sort: "deadline.timestamp",
                    }
                    , "className": "deadline"
                },
                {
                    data: "deliveryAvailable",
                    render: function (data, type, row) {
                        return ((data === true) ? 'Yes' : 'No') + (row.assetLogs !== '' && row.status != "Published" ? " <span class='dijitInline dijitIcon epi-iconWarning ' style='color: orange; font-weight: bold;' title='" + row.assetLogs + "'></span>" : "");
                    }
                    , "className": "delivery"
                },
            ],
            "columnDefs": [
                {
                    "targets": [0],
                    "orderable": false,

                },
                {
                    "targets": [1],
                    "render": project_cell_name_render,
                },
                {
                    "targets": [2],
                    "render": project_cell_status_render,
                }, {
                    "targets": [3],
                    "render": project_cell_action_render,
                    "orderable": false,
                },
                {
                    "targets": [4],
                    "render": project_cell_freewayid_render,
                }, {
                    "targets": [5],
                    "type": "num",
                },
                {
                    "targets": [6],
                    "type": "num",
                },
                {
                    "targets": [7],
                },
                {
                    "targets": [8],
                },
                {
                    "targets": [9],
                    "render": project_cell_deadline_render
                }
            ],
            "order": [[8, "desc"]],
            'createdRow': function (row, data, dataIndex) {
                $n(row).attr('project-id', data.Id).attr('project-percentage-completed', data.PercentageCompleted);
            },
        });

        $n('div.dataTables_filter').hide();

        function project_cell_action_render(data, type, row, meta) {
            var actions = row.allowActions;
            var buttonGroup = '<div class="btn-group">';

            if (actions && actions != null) {

                for (var i = 0; i < actions.length; i++) {
                    var action = actions[i];

                    if (action == 0) {
                        buttonGroup += '<button type = "button" class="btn btn-danger" onclick="LionBridgeConnectorJs.onEditProject(\'' + row.itemLink + '\')">Edit Project</button>';
                    }
                    if (action == 1) {
                        buttonGroup += '<button type = "button" class="btn btn-danger" onclick="LionBridgeConnectorJs.onEditProject(\'' + row.itemLink + '\')">View Project</button>';
                    }
                }

                buttonGroup +=
                    '<button type="button" class="btn dropdown-toggle" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">' +
                    '<span class="caret"></span>' +
                    '<span class="sr-only">Toggle Dropdown</span>' +
                    '</button>';
                buttonGroup += '<ul class="dropdown-menu">';
                var isDisplayImport = false;
                var isDisplayPublish = false;

                for (var i = 0; i < actions.length; i++) {
                    var action = actions[i];

                    if (action == 0) {
                        buttonGroup += '<li onclick="LionBridgeConnectorJs.onEditProject(\'' + row.itemLink + '\')"><span>Edit Project</span></li>';
                    }
                    if (action == 1) {
                        buttonGroup += '<li onclick="LionBridgeConnectorJs.onEditProject(\'' + row.itemLink + '\')"><span>View Project</span></li>';
                    }
                    if (action == 2) {
                        buttonGroup += '<li onclick="LionBridgeConnectorJs.onTranslate(' + row.id + ', this)"><span>Send to Translation</span></li>';
                    }
                    if ((action == 3 || row.canImport) && !isDisplayImport) {
                        buttonGroup += '<li onclick="LionBridgeConnectorJs.onImport(' + row.id + ', this)"><span>Import All Available</span></li>';
                        isDisplayImport = true;
                    }
                    if ((action == 4 || row.canPublish) && !isDisplayPublish) {
                        buttonGroup += '<li onclick="LionBridgeConnectorJs.onPublish(' + row.id + ', this)"><span>Publish All Available</span></li>';
                        isDisplayPublish = true;
                    }
                    if (action == 5) {
                        if (row.archive) {
                            buttonGroup += '<li onclick="LionBridgeConnectorJs.onArchive(' + row.id + ', false, this)"><span>Unarchive Project</span></li>';
                        } else {
                            buttonGroup += '<li onclick="LionBridgeConnectorJs.onArchive(' + row.id + ', true, this)"><span>Archive Project</span></li>';
                        }
                    }
                    if (action == 6) {
                        buttonGroup += '<li onclick="LionBridgeConnectorJs.onCancel(' + row.id + ', this)"><span>Cancel Project</span></li>';
                    }

                    if (action == 7) {
                        buttonGroup += '<li onclick="LionBridgeConnectorJs.onRemove(' + row.id + ', this)"><span>Remove Project</span></li>';
                    }
                }
                buttonGroup += '</ul>';

            }

            buttonGroup += '</div >';            

            return buttonGroup;
        };

        function project_cell_deadline_render(data, type, row, meta) {
            return row.deadline.display + (row.overDue ? " <span class='dijitInline dijitIcon epi-iconWarning' style='color: orange; font-weight: bold;' title='The Requested Due Date has passed'></span>" : "");
        };

        function project_cell_status_render(data, type, row, meta) {

            return row.hasSameStatusAtLanguageLevel ? row.status : "<i>" + row.status + "</i>";
        };

        function project_cell_name_render(data, type, row, meta) {
            return '<a href="javascript:void(0);">' + row.projectName + '</a>' + (row.error && row.errorMessage != null ? " <span class='dijitInline dijitIcon epi-iconError' title='" + row.errorMessage + "'></span>" : "");
        };

        function project_cell_freewayid_render(data, type, row, meta) {
            if (row.freewayID === undefined || row.freewayID === '')
                return '';

            var freewayIds = row.freewayID.split(",");
            var links = "";
            for (var i = 0; i < freewayIds.length; i++) {
                var freewayId = freewayIds[i];
                links += '<a href="' + row.freewayLink + freewayId.replace("BV-", "") + '" rel="nofollow" target="_blank">' + freewayId + '</a></br>';
            }

            return links;
        };

        //end project
        //Assets: asset is child's project  : Project > Asset > Type
        //This varial datable child's row

        $n('#project5b83a1a738dc42f4b697404c2d324450 tbody').on('click', 'td.projectname, td.detail-project', function () {
            var tr = $n(this).closest('tr');
            var row = LionBridgeConnectorGrid.projectTable.row(tr);

            //alert('project click', row.data().Id);

            if (row.child.isShown()) {
                // This row is already open - close it
                destroyTransitionProjectLanguage(row);
                tr.removeClass('shown');
            }
            else {
                // Open this row
                createTransitionProjectLanguage(row, 'child-table'); // class is for background colour
                tr.addClass('shown');
            }
        });

        function destroyTransitionProjectLanguage(row) {
            var table = $n("table", row.child());

            //destroy
            table.detach();
            table.DataTable().destroy();

            // And then hide the row
            row.child.hide();
        }

        function createTransitionProjectLanguage(row) {
            var rowMain = row;
            var rowid = row.data().id;
            // This is the table we'll convert into a DataTable
            var table = $n('<table style="height: 100%; overflow: auto;" class="second-level"/>');
            var tableTemplate = $n('#pjlanguage7341e559090c45f6a92e15552e27beb3');
            table.html(tableTemplate.html());

            // Display it the child row
            row.child(table).show();

            // Initialise as a DataTable
            var assetsTable = table.DataTable({
                "orderCellsTop": true,
                "fixedHeader": true,
                "searching": false,
                "lengthChange": false,
                "autoWidth": false,
                "paging": false,
                "info": false,
                "ajax": {
                    "url": LionBridgeConnectorJs.projectTranslationLanguageServiceUrl + rowid,
                },
                "columns": [
                    {
                        "className": 'detail-project-language',
                        "data": null,
                        "defaultContent": ''
                    },
                    { "data": "assets", "className": "project-language", "display": "Assets" },
                    { "data": "sourceLanguages", "className": "sourcelanguage" },
                    { "data": "targetLanguages", "className": "targetlanguage" },
                    { "data": "status", "className": "status" },
                    { "data": "actions" },
                    //{ "data": "DeliveryAvailable" },
                ],
                "columnDefs": [
                    {
                        "targets": [0],
                        "orderable": false,
                    },
                    {
                        "targets": [1],
                        "render": asset_cell_name_render,
                    },
                    {
                        "targets": [5],
                        "render": asset_cell_action_render,
                        "orderable": false,
                    }
                ],
                "order": [[1, "desc"]],
                'createdRow': function (row, data, dataIndex) {
                    $n(row).attr('project-id', rowid);
                },
                "fnInitComplete": function (oSettings, json) {
                    if (json && json.parent) {
                        if (json.parent.status !== rowMain.data().status) {
                            var newStatus = project_cell_status_render(null, null, json.parent, null);
                            LionBridgeConnectorGrid.projectTable.cell({ row: rowMain.index(), column: 2 }).data(newStatus);
                            var newAction = project_cell_action_render(null, null, json.parent, null);
                            LionBridgeConnectorGrid.projectTable.cell({ row: rowMain.index(), column: 3 }).data(newAction);
                        }
                    }
                }
            });
            LionBridgeConnectorGrid.assetsListTable[rowid] = assetsTable;
        }
        function asset_cell_action_render(data, type, row, meta) {
            var buttonGroup = '';
            var actions = row.allowActions;

            if (actions && actions != null) {
                buttonGroup = '<div class="btn-group">';
                for (var i = 0; i < actions.length; i++) {
                    var action = actions[i];

                    if (action == 3) {
                        buttonGroup += '<button type = "button" class="btn btn-danger" onclick="LionBridgeConnectorJs.onImportByLanguage(' + row.projectId + ',\'' + row.targetLanguages + '\', this)">Import</button>';
                    }
                    if (action == 4) {
                        buttonGroup += '<button type = "button" class="btn btn-danger" onclick="LionBridgeConnectorJs.onPublishByLanguage(' + row.projectId + ',\'' + row.targetLanguages + '\', this)">Publish</button>';
                    }
                }
                buttonGroup += '</div >';
            }

            return buttonGroup;
        };
        function asset_cell_name_render(data, type, row, meta) {
            return '<a href="javascript:void(0);">' + row.assets + '</a>' + (row.serviceErrorMessage && row.serviceErrorMessage !== "" ? " <span class='dijitInline dijitIcon epi-iconError' title='" + row.serviceErrorMessage + "'></span>" : "");
        };
        //End Asset

        //Type: Type is child's Assets  : Project > Asset > Type
        $n('#project5b83a1a738dc42f4b697404c2d324450 tbody').on('click', 'td.project-language, td.detail-project-language', function () {
            //alert('asset click');

            var tr = $n(this).closest('tr');
            var row = LionBridgeConnectorGrid.assetsListTable[tr.attr('project-id')].row(tr);

            if (row.child.isShown()) {
                // This row is already open - close it
                destroyProjectAssets(row);
                tr.removeClass('shown');
            }
            else {
                // Open this row
                createProjectAssets(row, 'child-table'); // class is for background colour
                tr.addClass('shown');
            }
        });

        function destroyProjectAssets(row) {
            var table = $n("table", row.child());
            table.detach();
            table.DataTable().destroy();

            // And then hide the row
            row.child.hide();
        }

        function createProjectAssets(row) {
            var rowid = row.data().projectId;
            var targetLanguages = row.data().targetLanguages;
            // This is the table we'll convert into a DataTable
            var table = $n('<table style="height: 100%; overflow: auto;" class="third-level"/>');
            var tableTemplate = $n('#pjasset25a496a334be4dc0b558af79b2d1946e');
            table.html(tableTemplate.html());

            // Display it the child row
            row.child(table).show();

            // Initialise as a DataTable
            var typesTable = table.DataTable({
                "processing": true,
                "serverSide": true,
                "orderCellsTop": true,
                "fixedHeader": true,
                "searching": false,
                "autoWidth": false,
                "lengthChange": false,
                "pageLength": pageSize,
                "info": false,
                "ajax": {
                    "url": LionBridgeConnectorJs.projectAssetServiceUrl + rowid + "?language=" + targetLanguages,
                    "data": function (d) {
                        if (d.order.length > 0) {
                            d.ordercolumn = d.columns[d.order[0].column].data;
                            d.orderby = d.order[0].dir;
                        }
                        d.order = '';
                        d.columns = '';
                        d.search = '';
                    }
                },
                "columns": [
                    { "data": "type", "className": "project-language-asset" },
                    { "data": "name" },
                    { "data": "location" },
                    { "data": "link" },
                    //{ "data": "Id" },
                ],
                "order": [[0, "desc"]],
                "columnDefs": [
                    {
                        "targets": [3],
                        "render": project_cell_asset_link_render,
                    }
                ]
            });
        }

        function project_cell_asset_link_render(data, type, row, meta) {
            if (row.link === undefined || row.link === '')
                return '';

            return '<a href="' + row.link + '" rel="nofollow" target="_blank" status="' + row.status + '" assetId="' + row.assetID + '">' + row.link + '</a>';
        };

        //End Type

    }

    function destroy() {
        if ($n.fn.DataTable.isDataTable("#project5b83a1a738dc42f4b697404c2d324450")) {
            LionBridgeConnectorGrid.projectTable.clear().destroy();
        }
    }

    function onReloadGrid() {
        if (LionBridgeConnectorGrid !== undefined && LionBridgeConnectorGrid.projectTable !== undefined) {
            LionBridgeConnectorGrid.projectTable.ajax.reload();
            LionBridgeConnectorGrid.projectTable.order([8, 'desc']).draw();
        }
    }

    function clearFilter() {
        var i = 0;
        $n('#project5b83a1a738dc42f4b697404c2d324450 thead tr:eq(0) th').each(function (i) {
            var input = $n('input', this);
            if (input !== undefined && input !== null && input.length !== 0) {
                if (input.val() !== '') {
                    input.val('');
                    LionBridgeConnectorGrid.projectTable.column(i).search(input.val()).draw();
                }
            }
            i++;
        });
    }

    function refreshChildGrid(item) {
        var table = $n(item).closest('table');
        if (table !== undefined)
            table.DataTable().ajax.reload();


    }

    function onToggleArchivingView(item) {
        var archiving = LionBridgeConnectorJs.onGetArchiving() === "true";
        archiving = !archiving;

        if (item) {
            var archiveButton = document.getElementById(item.id);
            if (archiveButton) {
                if (archiving) {
                    archiveButton.innerHTML = LionBridgeConnectorConstant.viewUnarchivedJobs;
                } else {
                    archiveButton.innerHTML = LionBridgeConnectorConstant.viewArchivedJobs;
                }
            }
        }              

        LionBridgeConnectorJs.onSetArchiving(archiving);

        if (LionBridgeConnectorGrid !== undefined && LionBridgeConnectorGrid.projectTable !== undefined) {
            LionBridgeConnectorGrid.projectTable.ajax.url(LionBridgeConnectorJs.projectServiceUrl + archiving);
            LionBridgeConnectorGrid.onReloadGrid();
        }
    }

    function onRegisterClass() {
        var form = $n('#project5b83a1a738dc42f4b697404c2d324450').closest('form');
        if (!$n(form).hasClass('lb_dashboard'))
            $n(form).addClass('lb_dashboard');

        var body = $n('#project5b83a1a738dc42f4b697404c2d324450').closest('body');
        if (!$n(body).hasClass('lb_body_dashboard'))
            $n(body).addClass('lb_body_dashboard');
    }

    return {
        onRenderGrid: onRenderGrid,
        assetsListTable: assetsListTable,
        projectTable: projectTable,
        destroy: destroy,
        onReloadGrid: onReloadGrid,
        clearFilter: clearFilter,
        refreshChildGrid: refreshChildGrid,
        onToggleArchivingView: onToggleArchivingView,
        onRegisterClass: onRegisterClass
    }

})();

